@@ -10,18 +10,17 @@ class SwapTrade(str, Enum):
     REPLACE_ORDER = "/openApi/swap/v1/trade/cancelReplace"
     CLOSE_POSITION = "/openApi/swap/v1/trade/closePosition"
     CLOSE_ALL_POSITIONS = "/openApi/swap/v2/trade/closeAllPositions"
-    
-    QUERY_ALL_OPEN_ORDERS = "/openApi/swap/v2/trade/openOrders"
+
     QUERY_ORDER_DETAIL = "/openApi/swap/v2/trade/order"
+    QUERY_ALL_OPEN_ORDERS = "/openApi/swap/v2/trade/openOrders"
     QUERY_ORDER_HISTORY = "/openApi/swap/v2/trade/allOrders"
-    
-    QUERY_MARGIN_TYPE = "/openApi/swap/v2/trade/marginType"
+
     CHANGE_MARGIN_TYPE = "/openApi/swap/v2/trade/marginType"
-    SET_LEVERAGE = "/openApi/swap/v2/trade/marginType"
+    QUERY_MARGIN_TYPE = "/openApi/swap/v2/trade/marginType"
+    SET_LEVERAGE = "/openApi/swap/v2/trade/leverage"
+    QUERY_LEVERAGE = "/openApi/swap/v2/trade/leverage"
     SET_POSITION_MODE = "/openApi/swap/v1/positionSide/dual"
     QUERY_POSITION_MODE = "/openApi/swap/v1/positionSide/dual"
-    
 
     def __str__(self) -> str:
         return self.value
-    
\ No newline at end of file
